==> gtkatlantic_0.4.4.orig.tar.gz: gtkatlantic-0.4.4/src/game.h <==
/*
 *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
 *
 *
 *  Copyright (C) 2002-2010 Rochet Sylvain
 *
 *  gtkatlantic is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

gboolean create_home_directory();
void read_config_files();
gboolean connect_get_valid_id(gint32 *idconnect);
void create_connection_metaserver(gint32 gametype);
void create_connection_get_games(gchar *host, gint32 port);
void text_insert_message(gchar* text, gint32 lenght);
void text_insert_chat(gchar* text, gint32 lenght);
void game_alloc();
void game_free();
gboolean game_get_valid_player_slot(gint32 *playerslot);
gint32 get_player_slot_with_playerid(gint32 playerid);
gint32 get_playerlistcard_id_with_estate(gint32 estate);
gboolean game_get_valid_command_slot(gint32 *commandslot);
gint32 get_command_button_slot_with_command(gchar *command);
void parse_specific_chat_message(gchar *message);
void parse_specific_send_message(gchar *message);
void game_sort_playerlist_by_playerid();
void game_write_cookie(gchar *cookie);
gboolean game_get_valid_card_slot(gint32 *cardslot);
gint32 get_card_slot_with_cardid(gint32 cardid);
gint32 get_playerid_by_playername(gchar *name);
gint32 game_nb_players();
gboolean game_get_valid_trade_slot(gint32 *tradeslot);
gint32 get_trade_slot_with_tradeid(gint32 tradeid);
gint32 get_estateid_by_estatename(gchar *name);
void game_buildplayerlist();
gint32 game_get_assets_player(gint32 playerid);
void game_update_tokens();
void game_start_move_token(gint32 playerid);
gboolean game_move_tokens();
void game_delete_player(gint32 id);

==> gtkatlantic_0.5.0.orig.tar.gz: gtkatlantic-0.5.0/src/game.h <==
/*
 *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
 *
 *
 *  Copyright © 2002-2014 Sylvain Rochet
 *
 *  gtkatlantic is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "global.h"

gboolean create_home_directory();
void read_config_files();
gboolean connect_get_valid_id(gint32 *idconnect);
void create_connection_metaserver(gint32 gametype);
void create_connection_get_games(gchar *host, gint32 port);
void text_insert_message(gchar* text, gint32 lenght);
void text_insert_chat(gchar* text, gint32 lenght);
game *game_new(gint32 id);
void game_free(gint32 id);
game *game_find(gint32 id);
void game_quit();
gint32 game_new_player_slot(gint32 playerid);
gint32 get_player_slot_with_playerid(gint32 playerid);
gint32 get_playerlistcard_id_with_estate(gint32 estate);
gboolean game_get_valid_command_slot(gint32 *commandslot);
gint32 get_command_button_slot_with_command(gchar *command);
void parse_specific_chat_message(gchar *message);
void parse_specific_send_message(gchar *message);
void game_sort_playerlist_by_playerid();
void game_switch_status();
void game_write_cookie();
gboolean game_get_valid_card_slot(gint32 *cardslot);
gint32 get_card_slot_with_cardid(gint32 cardid);
gint32 get_playerid_by_playername(gchar *name);
gint32 game_nb_players();
gboolean game_get_valid_trade_slot(gint32 *tradeslot);
gint32 get_trade_slot_with_tradeid(gint32 tradeid);
gint32 get_estateid_by_estatename(gchar *name);
void game_buildplayerlist();
gint32 game_get_assets_player(gint32 playerid);
void game_update_tokens();
void game_initiate_token_movement();
gboolean game_move_tokens();
void game_free_player(gint32 id);
